destroyRewarded static method
Cleans up system resources allocated for the rewarded ad.
Implementation
static void destroyRewarded({required String adUnitId}) {
_methodChannel.invokeMethod('destroyRewarded', {'adUnitId': adUnitId});
}
Cleans up system resources allocated for the rewarded ad.
static void destroyRewarded({required String adUnitId}) {
_methodChannel.invokeMethod('destroyRewarded', {'adUnitId': adUnitId});
}