loadBanner static method

void loadBanner({
  1. required String adUnitId,
})

Loads a new banner ad.

Note: The createBanner method automatically loads the first banner ad and starts auto-refresh. You only need to call this method if you paused the refresh.

Implementation

static void loadBanner({required String adUnitId}) {
  _methodChannel.invokeMethod('loadBanner', {'adUnitId': adUnitId});
}