setDoNotSell static method

void setDoNotSell(
  1. bool? doNotSell
)

Sets the user's CCPA do-not-sell status manually, bypassing CMP frameworks.

Pass true if the user opted out of data sale, false if sale is allowed, or null to clear the manual override and defer to CMP-provided signals (GPP/US Privacy). Can be called before initialize.

Implementation

static void setDoNotSell(bool? doNotSell) {
  _methodChannel.invokeMethod('setDoNotSell', {
    'doNotSell': doNotSell,
  });
}