CloudXAd class

Represents metadata about a loaded ad.

Properties

adFormat CloudXAdFormat
The ad format (banner, mrec, interstitial, rewarded).
final
adUnitId String
The ad unit ID configured in the CloudX dashboard.
final
hashCode int
The hash code for this object.
no setterinherited
networkName String
The ad network that won the auction (e.g., "meta", "admob").
final
networkPlacement String?
The network-specific placement ID (network-specific ID).
final
placement String?
Optional placement identifier for tracking.
final
revenue double
The eCPM revenue for this ad impression in USD.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited