CloudXAdFormat enum

Represents an ad format.

Inheritance
Available extensions

Values

Banner ad format.

const CloudXAdFormat('banner')
mrec → const CloudXAdFormat

MREC ad format.

const CloudXAdFormat('mrec')
interstitial → const CloudXAdFormat

Interstitial ad format.

const CloudXAdFormat('interstitial')
rewarded → const CloudXAdFormat

Rewarded ad format.

const CloudXAdFormat('rewarded')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudXAdFormat>
A constant List of the values in this enum, in order of their declaration.