CloudXErrorCode class abstract

Known CloudX error codes.

Use these to handle specific error scenarios programmatically.

Constructors

CloudXErrorCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adAlreadyShowing → const int
adapterAdExpired → const int
adapterAdFrequencyCapped → const int
adapterAdNotReady → const int
adapterBadRequest → const int
adapterBidTokenNotSupported → const int
adapterBidTokenTimeout → const int
adapterDisplayFailed → const int
adapterInitializationError → const int
adapterInternalError → const int
adapterInvalidConfiguration → const int
adapterInvalidLoadState → const int
adapterInvalidServerExtras → const int
adapterLoadTimeout → const int
adapterMissingActivity → const int
adapterMissingNativeAdAssets → const int
adapterNoConnection → const int
adapterNoFill → const int
adapterNotInitialized → const int
adapterRewardError → const int
adapterServerError → const int
adapterTimeout → const int
adapterWebviewError → const int
adNotFound → const int
adNotReady → const int
adsDisabled → const int
displayHostUnavailable → const int
dontKeepActivitiesEnabled → const int
internalError → const int
invalidAdUnit → const int
invalidAppKey → const int
loadFailed → const int
The load failed for a reason with no more specific code. Read CloudXError.message.
loadNotAllowedWhileShowing → const int
loadRejectedConcurrency → const int
loadRejectedTooManyConcurrentLoads → const int
networkClientError → const int
networkError → const int
networkInvalidResponse → const int
networkNoConnection → const int
networkServerError → const int
networkTimeout → const int
networkTooManyRequests → const int
noAdaptersFound → const int
noFill → const int
noNetworksConfigured → const int
notInitialized → const int
sdkDisabled → const int