errorCode property
The native error code, one of the CloudXErrorCode constants.
Null on success, and null on failure when the native SDK reported no code.
Implementation
final int? errorCode;
The native error code, one of the CloudXErrorCode constants.
Null on success, and null on failure when the native SDK reported no code.
final int? errorCode;