CloudXLogLevel enum
Log level for the CloudX SDK.
Controls verbosity of SDK logging output. Set via CloudX.setMinLogLevel.
Values
- verbose → const CloudXLogLevel
-
const CloudXLogLevel(0) - debug → const CloudXLogLevel
-
const CloudXLogLevel(1) - info → const CloudXLogLevel
-
const CloudXLogLevel(2) - warn → const CloudXLogLevel
-
const CloudXLogLevel(3) - error → const CloudXLogLevel
-
const CloudXLogLevel(4) - none → const CloudXLogLevel
-
const CloudXLogLevel(-1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CloudXLogLevel> - A constant List of the values in this enum, in order of their declaration.