CloudXRevenuePlatform class

Mediation platform a publisher reports impression-level revenue for via CloudX.reportRevenueData.

Intentionally not an enum so future platforms can be added without making the public API a closed set.

Constructors

CloudXRevenuePlatform.custom(String name)
A platform for any mediation SDK without a dedicated constant.
const
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
Stable platform name sent to CloudX services.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

adMob → const CloudXRevenuePlatform
Google AdMob mediation.
gam → const CloudXRevenuePlatform
Google Ad Manager.
inMobi → const CloudXRevenuePlatform
InMobi mediation.
topOn → const CloudXRevenuePlatform
TopOn mediation.