CloudXReward class

Represents a reward granted to the user after watching a rewarded ad.

Properties

amount int
The reward amount (e.g., 100, 1000).
final
hashCode int
The hash code for this object.
no setterinherited
label String
The reward label/currency (e.g., "coins", "gems").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited