cloudx library
Classes
- CloudX
- The main CloudX Flutter SDK class.
- CloudXAd
- Represents metadata about a loaded ad.
- CloudXAdFormat
- Format of an ad.
- CloudXAdListener
- Base listener for all CloudX ad types.
- CloudXAdViewListener
- Listener for banner and MREC ad events.
- CloudXArbiterBid
-
A bid candidate submitted to
CloudX.arbiter. - CloudXArbiterConfiguration
-
The bids compared by one
CloudX.arbitercall. - CloudXArbiterPlatform
- Platform participating in a Trusted Arbiter auction.
- CloudXArbiterPrecision
- Revenue precision reported by a mediation platform for an arbiter bid.
- CloudXArbiterResult
-
Outcome of one
CloudX.arbitercall. - CloudXError
- Represents an error from the CloudX SDK.
- CloudXErrorCode
- Known CloudX error codes.
- CloudXFullscreenAdListener
- Base listener for fullscreen ad types (interstitial and rewarded).
- CloudXInitializationResult
- The outcome of CloudX.initialize.
- CloudXInterstitialListener
- Listener for interstitial ad events.
- CloudXRevenueData
-
Impression-level revenue observed by the publisher, passed to
CloudX.reportRevenueData. - CloudXRevenuePlatform
-
Mediation platform a publisher reports impression-level revenue for via
CloudX.reportRevenueData. - CloudXRevenuePrecision
-
Precision of a revenue value reported through
CloudX.reportRevenueData. - CloudXReward
- Represents a reward granted to the user after watching a rewarded ad.
- CloudXRewardedListener
- Listener for rewarded ad events.
Enums
- CloudXAdViewPosition
- Represents where an ad view should be positioned on screen.
- CloudXLogLevel
- Log level for the CloudX SDK.