cloudx library

Classes

CloudX
The main CloudX Flutter SDK class.
CloudXAd
Represents metadata about a loaded ad.
CloudXAdListener
Base listener for all CloudX ad types.
CloudXAdView
Displays a native AdView for a banner or MREC ad using a platform view.
CloudXAdViewListener
Listener for banner and MREC ad events.
CloudXConfiguration
Configuration returned after successful SDK initialization.
CloudXError
Represents an error from the CloudX SDK.
CloudXErrorCode
Known CloudX error codes.
CloudXFullscreenAdListener
Base listener for fullscreen ad types (interstitial and rewarded).
CloudXInterstitialListener
Listener for interstitial ad events.
CloudXReward
Represents a reward granted to the user after watching a rewarded ad.
CloudXRewardedListener
Listener for rewarded ad events.

Enums

CloudXAdFormat
Represents an ad format.
CloudXAdViewPosition
Represents where an ad view should be positioned on screen.
CloudXLogLevel
Log level for the CloudX SDK.