CloudXAdViewPosition enum
Represents where an ad view should be positioned on screen.
Ad views are positioned as native overlays on top of Flutter content, rather than being embedded in the Flutter widget tree. This allows for sticky ads that stay fixed while content scrolls underneath.
Can be used with banners, MRECs, and other ad view types.
Values
- topLeft → const CloudXAdViewPosition
-
Top left of the screen
const CloudXAdViewPosition('top_left') - topCenter → const CloudXAdViewPosition
-
Top center of the screen
const CloudXAdViewPosition('top_center') - topRight → const CloudXAdViewPosition
-
Top right of the screen
const CloudXAdViewPosition('top_right') - centerLeft → const CloudXAdViewPosition
-
Center left of the screen
const CloudXAdViewPosition('center_left') - centered → const CloudXAdViewPosition
-
Center of the screen
const CloudXAdViewPosition('centered') - centerRight → const CloudXAdViewPosition
-
Center right of the screen
const CloudXAdViewPosition('center_right') - bottomLeft → const CloudXAdViewPosition
-
Bottom left of the screen
const CloudXAdViewPosition('bottom_left') - bottomCenter → const CloudXAdViewPosition
-
Bottom center of the screen
const CloudXAdViewPosition('bottom_center') - bottomRight → const CloudXAdViewPosition
-
Bottom right of the screen
const CloudXAdViewPosition('bottom_right')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Internal value for platform channel communication
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CloudXAdViewPosition> - A constant List of the values in this enum, in order of their declaration.