adUnitId property
Mediation-platform ad unit id, if known. Report the id you passed to the arbiter bid so CloudX attributes the realized price to that ad unit.
Implementation
final String? adUnitId;
Mediation-platform ad unit id, if known. Report the id you passed to the arbiter bid so CloudX attributes the realized price to that ad unit.
final String? adUnitId;